﻿
using System;
using System.Data;
using System.Drawing;
using System.Windows.Forms;

using MindFusion.Spreadsheet;


namespace SpreadsheetAutoFilter
{
	public partial class Form1 : Form
	{
		public Form1()
		{
			InitializeComponent();

			// Load the data
			LoadData();

			// Make sure the filled cells display the default borders
			workbookView1.DrawFilledCellBorders = true;

			// Handle the necessary events
			workbookView1.ActiveCellChanged += OnActiveCellChanged;

			// Turn autofiltering on
			workbook1.Worksheets[0].CellRanges["A1"].AutoFilter();
			workbook1.Worksheets[0].CellRanges["A1"].AutoFilter(6, "<>1", AutoFilterOperator.Or, null, true);
		}

		private void LoadData()
		{
			// Create a worksheet representing the data
			var data = ordersTableAdapter1.GetData();
			var sheet = workbook1.Worksheets.Add(nwindDataSet1.Orders.TableName);

			sheet.BeginInit();
			foreach (DataColumn column in data.Columns)
			{
				var sheetColumn = sheet.Columns[column.Ordinal];
				sheet.Cells[column.Ordinal, 0].Data = column.Caption;
			}

			// Style the header cells
			var headerStyle = sheet.CellRanges[0, 0, data.Columns.Count - 1, 0].Style;
			headerStyle.Background = new MindFusion.Drawing.SolidBrush(Color.FromArgb(251, 246, 221));
			headerStyle.FontBold = true;

			int i = 1;
			foreach (DataRow row in data.Rows)
			{
				foreach (DataColumn column in data.Columns)
					sheet.Cells[column.Ordinal, i].Data = row[column];
				i++;
			}

			workbookView1.ActiveWorksheet = sheet;
			workbookView1.ResizeColumnsToFit(0, data.Columns.Count - 1);
			Measure defaultColumnWidth = "48pt";
			for (int c = 0; c < data.Columns.Count; c++)
			{
				if (sheet.Columns[c].Width.Amount < defaultColumnWidth.Amount)
					sheet.Columns[c].Width = defaultColumnWidth;
			}
			sheet.EndInit();

			UpdateActiveRow();
		}

		private void OnActiveCellChanged(object sender, EventArgs e)
		{
			// Highlight the row containing the selection
			UpdateActiveRow();
		}

		private void UpdateActiveRow()
		{
			int newActiveRow = workbookView1.ActiveCell.Row;
			if (newActiveRow == activeRow)
				return;

			var sheet = workbookView1.ActiveWorksheet;
			if (activeRow != -1)
				sheet.Rows[activeRow].Style.Reset();
			activeRow = newActiveRow;
			if (activeRow != -1)
				sheet.Rows[activeRow].Style.Background = new MindFusion.Drawing.SolidBrush(Color.FromArgb(226, 236, 252));
		}


		private int activeRow = -1;
	}
}
